@@ -11,6 +11,7 @@ from aiohttp import web
 from cbpi.api import *
 import re
 import time
+import json
 
 logger = logging.getLogger(__name__)
 
@@ -29,44 +30,53 @@ async def calcGravity(polynom, tilt, unitsGravity):
 	return result
 
 @parameters([Property.Text(label="iSpindle", configurable=True, description="Enter the name of your iSpindel"),
-             Property.Select("Type", options=["Temperature", "Gravity/Angle", "Battery"], description="Select which type of data to register for this sensor. For Angle, Polynomial has to be left empty"),
+             Property.Select("Type", options=["Temperature", "Gravity/Angle", "Battery", "RSSI"], description="Select which type of data to register for this sensor. For Angle, Polynomial has to be left empty"),
              Property.Text(label="Polynomial", configurable=True, description="Enter your iSpindel polynomial. Use the variable tilt for the angle reading from iSpindel. Does not support ^ character."),
-             Property.Select("Units", options=["SG", "Brix", "°P"], description="Displays gravity reading with this unit if the Data Type is set to Gravity. Does not convert between units, to do that modify your polynomial.")])
+             Property.Select("Units", options=["SG", "Brix", "°P"], description="Displays gravity reading with this unit if the Data Type is set to Gravity. Does not convert between units, to do that modify your polynomial."),
+             Property.Sensor("FermenterTemp",description="Select Fermenter Temp Sensor that you want to provide to TCP Server")])
 
 class iSpindle(CBPiSensor):
     
     def __init__(self, cbpi, id, props):
         super(iSpindle, self).__init__(cbpi, id, props)
         self.value = 0
-        self.key = self.props.iSpindle
-        self.Polynomial = 'tilt' if self.props.Polynomial == '' else self.props.Polynomial
+        self.key = self.props.get("iSpindle", None)
+        self.Polynomial = self.props.get("Polynomial", "tilt")
+        self.temp_sensor_id = self.props.get("FermenterTemp", None)
         self.time_old = 0
 
     def get_unit(self):
-        if self.props.Type == "Temperature":
+        if self.props.get("Type") == "Temperature":
             return "°C" if self.get_config_value("TEMP_UNIT", "C") == "C" else "°F"
-        elif self.props.Type == "Gravity/Angle":
+        elif self.props.get("Type") == "Gravity/Angle":
             return self.props.Units
-        elif self.props.Type == "Battery":
+        elif self.props.get("Type") == "Battery":
             return "V"
+        elif self.props.get("Type") == "RSSI":
+            return "dB"
         else:
             return " "
 
     async def run(self):
         global cache
+        global fermenter_temp
+        Spindle_name = self.props.get("iSpindle") 
         while self.running == True:
             try:
                 if (float(cache[self.key]['Time']) > float(self.time_old)):
                     self.time_old = float(cache[self.key]['Time'])
-                    if self.props.Type == "Gravity/Angle":
-                        self.value = await calcGravity(self.Polynomial, cache[self.key]['Angle'], self.props.Units)
+                    if self.props.get("Type") == "Gravity/Angle":
+                        self.value = await calcGravity(self.Polynomial, cache[self.key]['Angle'], self.props.get("Units"))
                     else:
                         self.value = float(cache[self.key][self.props.Type])
                     self.log_data(self.value)
                     self.push_update(self.value)
+                self.push_update(self.value,False)
+                #self.cbpi.ws.send(dict(topic="sensorstate", id=self.id, value=self.value))
+                
             except Exception as e:
                 pass
-            await asyncio.sleep(1)
+            await asyncio.sleep(2)
 
     def get_state(self):
         return dict(value=self.value)
@@ -80,10 +90,14 @@ class iSpindleEndpoint(CBPiExtension):
         '''
         self.pattern_check = re.compile("^[a-zA-Z0-9,.]{0,10}$")
         self.cbpi = cbpi
+        self.sensor_controller : SensorController = cbpi.sensor
         # register component for http, events
         # In addtion the sub folder static is exposed to access static content via http
         self.cbpi.register(self, "/api/hydrometer/v1/data")
 
+    async def run(self):
+        await self.get_spindle_sensor()
+
     @request_mapping(path='', method="POST", auth_required=False)
     async def http_new_value3(self, request):
         import time
@@ -91,17 +105,13 @@ class iSpindleEndpoint(CBPiExtension):
         ---
         description: Get iSpindle Value
         tags:
-        - iSpindle Sensor
-        consumes:
-        - application/json
+        - iSpindle 
         parameters:
         - name: "data"
           in: "body"
           description: "Data"
           required: "name"
           type: "object"
-          properties: 
-          name: 
           type: string
         responses:
             "204":
@@ -113,14 +123,41 @@ class iSpindleEndpoint(CBPiExtension):
             data = await request.json()
         except Exception as e:
             print(e)
+        logging.info(data)
         time = time.time()
         key = data['name']
         temp = round(float(data['temperature']), 2)
         angle = data['angle']
         battery = data['battery']
-        cache[key] = {'Time': time,'Temperature': temp, 'Angle': angle, 'Battery': battery}
+        try:
+            rssi = data['RSSI']
+        except:
+            rssi = 0
+        cache[key] = {'Time': time,'Temperature': temp, 'Angle': angle, 'Battery': battery, 'RSSI': rssi}
 
-        return web.Response(status=204)
+
+    @request_mapping(path='/gettemp/{SpindleID}', method="POST", auth_required=False)
+    async def get_fermenter_temp(self, request):
+        SpindleID = request.match_info['SpindleID']
+        sensor_value = await self.get_spindle_sensor(SpindleID)
+        data = {'Temp': sensor_value}
+        return  web.json_response(data=data)
+
+    async def get_spindle_sensor(self, iSpindleID = None):
+        self.sensor = self.sensor_controller.get_state()
+        for id in self.sensor['data']:
+            if id['type'] == 'iSpindle':
+                name= id['props']['iSpindle']
+                if name == iSpindleID:
+                    try:
+                        sensor= id['props']['FermenterTemp']
+                    except:
+                        sensor = None
+                    if sensor is not None:
+                        sensor_value = self.cbpi.sensor.get_sensor_value(sensor).get('value')
+                    else:
+                        sensor_value = None
+                    return sensor_value
 
 def setup(cbpi):
     cbpi.plugin.register("iSpindle", iSpindle)
